[java-shib-idp2 COMMIT] in /branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp: authn/Saml2LoginCon...

noreply at shibboleth.net noreply at shibboleth.net
Mon Mar 4 15:41:25 EST 2013


Author: scantor
Date: Mon Mar  4 15:41:25 2013
New Revision: 3144

URL: http://svn.shibboleth.net/view/java-shib-idp2?rev=3144&view=rev
Log:
SIDP-499 - Complete patch with authenticated request tracking.

Modified:
    branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/authn/Saml2LoginContext.java
    branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/profile/saml2/SSOProfileHandler.java

Modified: branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/authn/Saml2LoginContext.java
URL: http://svn.shibboleth.net/view/java-shib-idp2/branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/authn/Saml2LoginContext.java?rev=3144&r1=3143&r2=3144&view=diff
==============================================================================
--- branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/authn/Saml2LoginContext.java (original)
+++ branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/authn/Saml2LoginContext.java Mon Mar  4 15:41:25 2013
@@ -62,6 +62,9 @@
     /** Serialized authentication request. */
     private String serialAuthnRequest;
 
+    /** Was the request authenticated when received. */
+    private boolean requestAuthenticated;
+    
     /** Unsolicited SSO indicator. */
     private boolean unsolicited;
 
@@ -153,6 +156,24 @@
     }
 
     /**
+     * Gets whether the message was authenticated when received.
+     * 
+     * @return whether the message was authenticated when received
+     */
+    public boolean isRequestAuthenticated() {
+        return requestAuthenticated;
+    }
+    
+    /**
+     * Sets whether the message was authenticated when received.
+     * 
+     * @param flag whether the message was authenticated when received
+     */
+    public void setRequestAuthenticated(boolean flag) {
+        requestAuthenticated = flag;
+    }
+    
+    /**
      * Serializes an authentication request into a string.
      * 
      * @param request the request to serialize

Modified: branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/profile/saml2/SSOProfileHandler.java
URL: http://svn.shibboleth.net/view/java-shib-idp2/branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/profile/saml2/SSOProfileHandler.java?rev=3144&r1=3143&r2=3144&view=diff
==============================================================================
--- branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/profile/saml2/SSOProfileHandler.java (original)
+++ branches/REL_2/src/main/java/edu/internet2/middleware/shibboleth/idp/profile/saml2/SSOProfileHandler.java Mon Mar  4 15:41:25 2013
@@ -227,6 +227,7 @@
             Saml2LoginContext loginContext = new Saml2LoginContext(relyingPartyId, requestContext.getRelayState(),
                     requestContext.getInboundSAMLMessage());
             loginContext.setUnsolicited(requestContext.isUnsolicited());
+            loginContext.setRequestAuthenticated(requestContext.isInboundSAMLMessageAuthenticated());
             loginContext.setAuthenticationEngineURL(authenticationManagerPath);
             loginContext.setProfileHandlerURL(HttpHelper.getRequestUriWithoutContext(httpRequest));
             loginContext.setDefaultAuthenticationMethod(rpConfig.getDefaultAuthenticationMethod());
@@ -480,6 +481,7 @@
 
         requestContext.setLoginContext(loginContext);
         requestContext.setUnsolicited(loginContext.isUnsolicited());
+        requestContext.setInboundSAMLMessageAuthenticated(loginContext.isRequestAuthenticated());
 
         requestContext.setInboundMessageTransport(in);
         requestContext.setInboundSAMLProtocol(SAMLConstants.SAML20P_NS);
@@ -825,10 +827,10 @@
         /**
          * Sets the unsolicited SSO indicator.
          * 
          * @param unsolicited unsolicited SSO indicator to set
          */
-        public void setUnsolicited(boolean unsolicited) {
-            this.unsolicited = unsolicited;
+        public void setUnsolicited(boolean flag) {
+            unsolicited = flag;
         }        
 
         /**
@@ -825,10 +827,10 @@
          * Sets the unsolicited SSO indicator.
          * 
-         * @param unsolicited unsolicited SSO indicator to set
+         * @param flag unsolicited SSO indicator to set
          */



More information about the commits mailing list